Command

Enum Command 

pub enum Command {
    Harvest {
        portal_url: Option<String>,
        type: PortalType,
        profile: Option<String>,
        portal: Option<String>,
        config: Option<PathBuf>,
        full_sync: bool,
        dry_run: bool,
        metadata_only: bool,
    },
    Embed {
        portal: Option<String>,
    },
    Search {
        query: String,
        limit: usize,
    },
    Export {
        format: ExportFormat,
        portal: Option<String>,
        limit: Option<usize>,
        output: Option<PathBuf>,
        config: Option<PathBuf>,
    },
    Stats,
}
Available CLI commands

Variants



Harvest

Harvest datasets from open data portals

Fields

portal_url: Option<String>

URL of a portal to harvest (ad-hoc, not from config)

type: PortalType

Portal type when harvesting an ad-hoc URL (ignored when using –portal or batch mode)

profile: Option<String>

DCAT profile when harvesting an ad-hoc DCAT URL (e.g., “sparql”)

portal: Option<String>

Harvest a specific portal by name from config file

config: Option<PathBuf>

Custom path to portals.toml configuration file

full_sync: bool

Force full sync even if incremental sync is available

dry_run: bool

Preview what would be harvested without writing to DB or calling embedding API

metadata_only: bool

Only harvest metadata (no embedding). Does not require an API key.



Embed

Generate embeddings for datasets that don’t have them yet

Fields

portal: Option<String>

Filter to a specific portal URL



Search

Search indexed datasets using semantic similarity

Fields

query: String

Search query text

limit: usize

Maximum number of results to return



Export

Export indexed datasets to various formats

Fields

format: ExportFormat

Output format for exported data

portal: Option<String>

Filter by source portal URL

limit: Option<usize>

Maximum number of datasets to export

output: Option<PathBuf>

Output directory (required for parquet format)

config: Option<PathBuf>

Custom path to portals.toml (for portal name resolution in parquet export)



Stats

Show database statistics